.. _gettingstarted:

Getting started
===============

.. sectionauthor:: Matt Swain <m.swain@me.com>

This page gives a introduction on how to get started with MolVS. This assumes you already have MolVS
:ref:`installed <install>`.

TODO...
